@@ -53,21 +53,22 @@ rpf.drm <- function(numChoices=5, dimensions=1, D=1, multidimensional) {
 setMethod("rpf.prob", signature(m="rpf.1dim.drm", param="numeric",
                                 theta="numeric"),
           function(m, param, theta) {
-            a <- param[1]
+            a <- param[1] * m@D
             b <- param[2]
             c <- param[3]
-            p <- c + (1-c)/(1+exp(-m@D*a*(theta-b)))
+            p <- c + (1-c)/(1+exp(-a*(theta-b)))
             cbind(1-p,p)
           })
 
-setMethod("rpf.logLik", signature(m="rpf.1dim.drm", param="numeric"),
-          function(m, param) {
-            a <- param[1]
+##' @references
+##' Embretson & Reise (2000, p. 184)
+setMethod("rpf.info", signature(m="rpf.1dim.drm", param="numeric",
+                                theta="numeric"),
+          function(m, param, theta) {
+            p <- rpf.prob(m, param, theta)
+            a <- param[1] * m@D
             c <- param[3]
-            sum(dlnorm(a, meanlog=m@a.prior.meanlog,
-                       sdlog=m@a.prior.sdlog, log=TRUE),
-                dbeta(c, shape1=m@c.prior.alpha-2,
-                      shape2=m@c.prior.beta-2, log=TRUE))
+            a^2 * (p[,1]/p[,2]) * ((p[,2]-c)^2/(1-c)^2)
           })
 
 setMethod("rpf.rparam", signature(m="rpf.1dim.drm"),
@@ -110,18 +111,6 @@ setMethod("rpf.prob", signature(m="rpf.mdim.drm", param="numeric",
             cbind(1-p,p)
           })
 
-setMethod("rpf.logLik", signature(m="rpf.mdim.drm", param="numeric"),
-          function(m, param) {
-            a <- param[1:m@dimensions] * m@D
-            p.rest <- param[-1:-m@dimensions]
-            b <- p.rest[1]
-            c <- p.rest[2]
-            sum(dlnorm(a, meanlog=m@a.prior.meanlog,
-                       sdlog=m@a.prior.sdlog, log=TRUE),
-                dbeta(c, shape1=m@c.prior.alpha-2,
-                      shape2=m@c.prior.beta-2, log=TRUE))
-          })
-
 setMethod("rpf.rparam", signature(m="rpf.mdim.drm"),
           function(m) {
             c(a=rlnorm(m@dimensions, meanlog=m@a.prior.meanlog,
